@@ -1,21 +1,9 @@
 /*
-    Copyright (C) 2001,2002 Carsten Pfeiffer <pfeiffer@kde.org>
-    Copyright (C) 2001 Michael Jarrett <michaelj@corel.com>
-    Copyright (C) 2009 Shaun Reich <shaun.reich@kdemail.net>
+    SPDX-FileCopyrightText: 2001, 2002 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2001 Michael Jarrett <michaelj@corel.com>
+    SPDX-FileCopyrightText: 2009 Shaun Reich <shaun.reich@kdemail.net>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kdirselectdialog_p.h"
@@ -32,16 +20,19 @@
 #include <QStringList>
 #include <QUrl>
 
-#include <kio/jobuidelegate.h>
+#include <KFileUtils>
+#include <KStandardShortcut>
 #include <kactioncollection.h>
 #include <kauthorized.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <kfileitemdelegate.h>
+#include <kfilewidget.h>
 #include <khistorycombobox.h>
-#include <kio/job.h>
-#include <kio/deletejob.h>
 #include <kio/copyjob.h>
+#include <kio/deletejob.h>
+#include <kio/job.h>
+#include <kio/jobuidelegate.h>
 #include <kio/mkdirjob.h>
 #include <kjobwidgets.h>
 #include <klocalizedstring.h>
@@ -53,22 +44,19 @@
 #include <ktoggleaction.h>
 #include <kurlcompletion.h>
 #include <kurlpixmapprovider.h>
-#include <kfilewidget.h>
-#include <KFileUtils>
-#include <KStandardShortcut>
 
 #include "kfiletreeview_p.h"
-#include <kfileplacesview.h>
 #include <kfileplacesmodel.h>
+#include <kfileplacesview.h>
 // ### add mutator for treeview!
 
 class KDirSelectDialog::Private
 {
 public:
     Private(bool localOnly, KDirSelectDialog *parent)
-        : m_parent(parent),
-          m_localOnly(localOnly),
-          m_comboLocked(false)
+        : m_parent(parent)
+        , m_localOnly(localOnly)
+        , m_comboLocked(false)
     {
     }
 
@@ -76,12 +64,11 @@ public:
     void saveConfig(KSharedConfigPtr config, const QString &group);
     void slotMkdir();
 
-    void slotCurrentChanged();
+    void slotCurrentChanged(const QUrl &url);
     void slotExpand(const QModelIndex &);
     void slotUrlActivated(const QString &);
     void slotComboTextChanged(const QString &);
     void slotContextMenuRequested(const QPoint &);
-    void slotNewFolder();
     void slotMoveToTrash();
     void slotDelete();
     void slotProperties();
@@ -135,9 +122,12 @@ void KDirSelectDialog::Private::slotMkdir()
         name = KFileUtils::suggestName(m_parent->url(), name);
     }
 
-    const QString directory = QInputDialog::getText(m_parent, i18nc("@title:window", "New Folder"),
+    const QString directory = QInputDialog::getText(m_parent,
+                                                    i18nc("@title:window", "New Folder"),
                                                     i18nc("@label:textbox", "Create new folder in:\n%1", where),
-                                                    QLineEdit::Normal, name, &ok);
+                                                    QLineEdit::Normal,
+                                                    name,
+                                                    &ok);
     if (!ok) {
         return;
     }
@@ -153,7 +143,7 @@ void KDirSelectDialog::Private::slotMkdir()
         folderurl.setPath(folderurl.path() + QLatin1Char('/') + *it);
         KIO::StatJob *job = KIO::stat(folderurl);
         KJobWidgets::setWindow(job, m_parent);
-        job->setDetails(KIO::StatNoDetails);  // We only want to know if it exists
+        job->setDetails(KIO::StatNoDetails); // We only want to know if it exists
         job->setSide(KIO::StatJob::DestinationSide);
         exists = job->exec();
         if (!exists) {
@@ -165,7 +155,7 @@ void KDirSelectDialog::Private::slotMkdir()
 
     if (exists) { // url was already existent
         QString which = folderurl.toDisplayString(QUrl::PreferLocalFile);
-        KMessageBox::sorry(m_parent, i18n("A file or folder named %1 already exists.", which));
+        KMessageBox::error(m_parent, i18n("A file or folder named %1 already exists.", which));
         // Select the existing dir (if a file with that name exists, it won't be selected since
         // we only show dirs here, this is cheaper than checking if the existing item is a file
         // or folder).
@@ -174,7 +164,7 @@ void KDirSelectDialog::Private::slotMkdir()
     }
 
     if (!writeOk) {
-        KMessageBox::sorry(m_parent, i18n("You do not have permission to create that folder."));
+        KMessageBox::error(m_parent, i18n("You do not have permission to create that folder."));
         return;
     }
 
@@ -182,16 +172,14 @@ void KDirSelectDialog::Private::slotMkdir()
     m_parent->setCurrentUrl(folderurl);
 }
 
-void KDirSelectDialog::Private::slotCurrentChanged()
+void KDirSelectDialog::Private::slotCurrentChanged(const QUrl &url)
 {
     if (m_comboLocked) {
         return;
     }
 
-    const QUrl u = m_treeView->currentUrl();
-
-    if (u.isValid()) {
-        m_urlCombo->setEditText(u.toDisplayString(QUrl::PreferLocalFile));
+    if (url.isValid()) {
+        m_urlCombo->setEditText(url.toDisplayString(QUrl::PreferLocalFile));
     } else {
         m_urlCombo->setEditText(QString());
     }
@@ -207,7 +195,7 @@ void KDirSelectDialog::Private::slotUrlActivated(const QString &text)
     m_urlCombo->addToHistory(url.toDisplayString());
 
     if (m_parent->localOnly() && !url.isLocalFile()) {
-        return;    //FIXME: messagebox for the user
+        return; // FIXME: messagebox for the user
     }
 
     QUrl oldUrl = m_treeView->currentUrl();
@@ -247,11 +235,6 @@ void KDirSelectDialog::Private::slotExpand(const QModelIndex &index)
     m_treeView->setExpanded(index, !m_treeView->isExpanded(index));
 }
 
-void KDirSelectDialog::Private::slotNewFolder()
-{
-    slotMkdir();
-}
-
 void KDirSelectDialog::Private::slotMoveToTrash()
 {
     const QUrl url = m_treeView->selectedUrl();
@@ -282,12 +265,12 @@ void KDirSelectDialog::Private::slotProperties()
 }
 
 KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget *parent)
-// #ifdef Q_OS_WIN
-//     : QDialog(parent, Qt::WindowMinMaxButtonsHint),
-// #else
-//     : QDialog(parent),
-// #endif
-     : d(new Private(localOnly, this))
+    // #ifdef Q_OS_WIN
+    //     : QDialog(parent, Qt::WindowMinMaxButtonsHint),
+    // #else
+    //     : QDialog(parent),
+    // #endif
+    : d(new Private(localOnly, this))
 {
     setWindowTitle(i18nc("@title:window", "Select Folder"));
 
@@ -297,14 +280,16 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     QFrame *page = new QFrame(this);
     topLayout->addWidget(page);
 
-    QPushButton *folderButton = new QPushButton;
+    QPushButton *folderButton = new QPushButton(this);
     KGuiItem::assign(folderButton, KGuiItem(i18nc("@action:button", "New Folder..."), QStringLiteral("folder-new")));
-    connect(folderButton, SIGNAL(clicked()), this, SLOT(slotNewFolder()));
+    connect(folderButton, &QPushButton::clicked, this, [this]() {
+        d->slotMkdir();
+    });
 
     m_buttons = new QDialogButtonBox(this);
     m_buttons->addButton(folderButton, QDialogButtonBox::ActionRole);
     m_buttons->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-    connect(m_buttons, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(m_buttons, &QDialogButtonBox::accepted, this, &QDialog::accept);
     connect(m_buttons, &QDialogButtonBox::rejected, this, &QDialog::reject);
     topLayout->addWidget(m_buttons);
 
@@ -318,8 +303,7 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     d->m_placesView->setObjectName(QStringLiteral("speedbar"));
     d->m_placesView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     d->m_placesView->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
-    connect(d->m_placesView, &KFilePlacesView::urlChanged,
-            this, &KDirSelectDialog::setCurrentUrl);
+    connect(d->m_placesView, &KFilePlacesView::urlChanged, this, &KDirSelectDialog::setCurrentUrl);
     hlay->addWidget(d->m_placesView);
     hlay->addLayout(mainLayout);
 
@@ -333,7 +317,7 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
 
     d->m_urlCombo = new KHistoryComboBox(page);
     d->m_urlCombo->setLayoutDirection(Qt::LeftToRight);
-    d->m_urlCombo->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);
+    d->m_urlCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);
     d->m_urlCombo->setTrapReturnKey(true);
     d->m_urlCombo->setIconProvider([](const QString &name) {
         return QIcon::fromTheme(KIO::iconNameForUrl(QUrl::fromUserInput(name)));
@@ -350,21 +334,27 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     d->m_actions->addAction(newFolder->objectName(), newFolder);
     newFolder->setIcon(QIcon::fromTheme(QStringLiteral("folder-new")));
     newFolder->setShortcuts(KStandardShortcut::createFolder());
-    connect(newFolder, SIGNAL(triggered(bool)), this, SLOT(slotNewFolder()));
+    connect(newFolder, &QAction::triggered, this, [this]() {
+        d->slotMkdir();
+    });
     d->m_contextMenu->addAction(newFolder);
 
     d->moveToTrash = new QAction(i18nc("@action:inmenu", "Move to Trash"), this);
     d->m_actions->addAction(d->moveToTrash->objectName(), d->moveToTrash);
     d->moveToTrash->setIcon(QIcon::fromTheme(QStringLiteral("user-trash")));
     d->moveToTrash->setShortcut(Qt::Key_Delete);
-    connect(d->moveToTrash, SIGNAL(triggered(bool)), this, SLOT(slotMoveToTrash()));
+    connect(d->moveToTrash, &QAction::triggered, this, [this]() {
+        d->slotMoveToTrash();
+    });
     d->m_contextMenu->addAction(d->moveToTrash);
 
     d->deleteAction = new QAction(i18nc("@action:inmenu", "Delete"), this);
     d->m_actions->addAction(d->deleteAction->objectName(), d->deleteAction);
     d->deleteAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
     d->deleteAction->setShortcut(Qt::SHIFT | Qt::Key_Delete);
-    connect(d->deleteAction, SIGNAL(triggered(bool)), this, SLOT(slotDelete()));
+    connect(d->deleteAction, &QAction::triggered, this, [this]() {
+        d->slotDelete();
+    });
     d->m_contextMenu->addAction(d->deleteAction);
 
     d->m_contextMenu->addSeparator();
@@ -380,7 +370,9 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     d->m_actions->addAction(propertiesAction->objectName(), propertiesAction);
     propertiesAction->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
     propertiesAction->setShortcut(Qt::ALT | Qt::Key_Return);
-    connect(propertiesAction, SIGNAL(triggered(bool)), this, SLOT(slotProperties()));
+    connect(propertiesAction, &QAction::triggered, this, [this]() {
+        d->slotProperties();
+    });
     d->m_contextMenu->addAction(propertiesAction);
 
     d->m_startURL = KFileWidget::getStartUrl(startDir, d->m_recentDirClass);
@@ -401,19 +393,29 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     mainLayout->addWidget(d->m_treeView, 1);
     mainLayout->addWidget(d->m_urlCombo, 0);
 
-    connect(d->m_treeView, SIGNAL(currentChanged(QUrl)),
-            SLOT(slotCurrentChanged()));
-    connect(d->m_treeView, SIGNAL(activated(QModelIndex)),
-            SLOT(slotExpand(QModelIndex)));
-    connect(d->m_treeView, SIGNAL(customContextMenuRequested(QPoint)),
-            SLOT(slotContextMenuRequested(QPoint)));
+    connect(d->m_treeView, &KFileTreeView::currentUrlChanged, this, [this](const QUrl &url) {
+        d->slotCurrentChanged(url);
+    });
 
-    connect(d->m_urlCombo, SIGNAL(editTextChanged(QString)),
-            SLOT(slotComboTextChanged(QString)));
-    connect(d->m_urlCombo, SIGNAL(activated(QString)),
-            SLOT(slotUrlActivated(QString)));
-    connect(d->m_urlCombo, SIGNAL(returnPressed(QString)),
-            SLOT(slotUrlActivated(QString)));
+    connect(d->m_treeView, &QAbstractItemView::activated, this, [this](const QModelIndex &index) {
+        d->slotExpand(index);
+    });
+
+    connect(d->m_treeView, &QWidget::customContextMenuRequested, this, [this](const QPoint &pos) {
+        d->slotContextMenuRequested(pos);
+    });
+
+    connect(d->m_urlCombo, &QComboBox::editTextChanged, this, [this](const QString &text) {
+        d->slotComboTextChanged(text);
+    });
+
+    connect(d->m_urlCombo, &QComboBox::textActivated, this, [this](const QString &text) {
+        d->slotUrlActivated(text);
+    });
+
+    connect(d->m_urlCombo, QOverload<const QString &>::of(&KComboBox::returnPressed), this, [this](const QString &text) {
+        d->slotUrlActivated(text);
+    });
 
     setCurrentUrl(d->m_startURL);
 }
@@ -468,9 +470,9 @@ void KDirSelectDialog::setCurrentUrl(const QUrl &url)
 
     if (url.scheme() != d->m_rootUrl.scheme()) {
         QUrl u(url);
-        //We need the url to end with / because some code ahead (kdirmodel) is expecting
-        //to find the / separator. It can happen that a valid url like smb: does not have
-        //one so we should add it.
+        // We need the url to end with / because some code ahead (kdirmodel) is expecting
+        // to find the / separator. It can happen that a valid url like smb: does not have
+        // one so we should add it.
         if (!u.toString().endsWith(QLatin1Char('/'))) {
             u.setPath(QStringLiteral("/"));
         }
@@ -479,11 +481,10 @@ void KDirSelectDialog::setCurrentUrl(const QUrl &url)
         d->m_rootUrl = u;
     }
 
-    //Check if url represents a hidden folder and enable showing them
+    // Check if url represents a hidden folder and enable showing them
     QString fileName = url.fileName();
-    //TODO a better hidden file check?
-    bool isHidden = fileName.length() > 1 && fileName[0] == QLatin1Char('.') &&
-                    (fileName.length() > 2 ? fileName[1] != QLatin1Char('.') : true);
+    // TODO a better hidden file check?
+    bool isHidden = fileName.length() > 1 && fileName[0] == QLatin1Char('.') && (fileName.length() > 2 ? fileName[1] != QLatin1Char('.') : true);
     bool showHiddenFiles = isHidden && !d->m_treeView->showHiddenFiles();
     if (showHiddenFiles) {
         d->showHiddenFoldersAction->setChecked(true);
@@ -518,10 +519,7 @@ void KDirSelectDialog::hideEvent(QHideEvent *event)
 }
 
 // static
-QUrl KDirSelectDialog::selectDirectory(const QUrl &startDir,
-                                       bool localOnly,
-                                       QWidget *parent,
-                                       const QString &caption)
+QUrl KDirSelectDialog::selectDirectory(const QUrl &startDir, bool localOnly, QWidget *parent, const QString &caption)
 {
     KDirSelectDialog myDialog(startDir, localOnly, parent);
 
@@ -532,7 +530,7 @@ QUrl KDirSelectDialog::selectDirectory(const QUrl &startDir,
     if (myDialog.exec() == QDialog::Accepted) {
         QUrl url = myDialog.url();
 
-        //Returning the most local url
+        // Returning the most local url
         if (url.isLocalFile()) {
             return url;
         }
@@ -608,5 +606,4 @@ void KDirSelectDialog::selectNameFilter(const QString &filter)
     Q_UNUSED(filter)
 }
 
-
 #include "moc_kdirselectdialog_p.cpp"
